@@ -106,7 +106,7 @@ class GithubData :
         evt = self._list_ev_thing_in_repo_dir()
         not_ignored = self._remove_ignored_files(evt)
         stg = [str(x) for x in not_ignored]
-        self._repo.add(stg)
+        porcelain.add(self._repo , stg)
         self._repo.stage(stg)
 
     def _set_defualt_data_suffix(
@@ -318,5 +318,3 @@ def get_github_token_pathes() :
             break
     rp.rmdir()
     return op
-
-##
