@@ -48,12 +48,8 @@ repo.commit_and_push(msg)
 repo.rmdir()
 
 ##
-import dulwich
-
-
 ur = 'https://github.com/imahdimir/test-private'
 
-dulwich.porcelain.clone(ur , checkout = True)
 
 ##
 
